==> igniteui-react-charts-18.2.0-beta.1.tgz: package/esm5/lib/ItemwiseStrategyBasedIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ItemwiseStrategyCalculationStrategy } from "./ItemwiseStrategyCalculationStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var ItemwiseStrategyBasedIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ItemwiseStrategyBasedIndicator, _super);
    function ItemwiseStrategyBasedIndicator() {
        return _super.call(this) || this;
    }
    ItemwiseStrategyBasedIndicator.prototype.get_up = function () {
        return new ItemwiseStrategyCalculationStrategy();
    };
    Object.defineProperty(ItemwiseStrategyBasedIndicator.prototype, "up", {
        get: function () {
            return this.get_up();
        },
        enumerable: false,
        configurable: true
    });
    ItemwiseStrategyBasedIndicator.prototype.u3 = function () {
        _super.prototype.u3.call(this);
        this.va = this.vb;
        this.uo.c = this.va;
    };
    ItemwiseStrategyBasedIndicator.$t = markType(ItemwiseStrategyBasedIndicator, 'ItemwiseStrategyBasedIndicator', StrategyBasedIndicator.$);
    return ItemwiseStrategyBasedIndicator;
}(StrategyBasedIndicator));
export { ItemwiseStrategyBasedIndicator };

==> igniteui-react-charts-18.5.2-beta.1.tgz: package/esm5/lib/ItemwiseStrategyBasedIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ItemwiseStrategyCalculationStrategy } from "./ItemwiseStrategyCalculationStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var ItemwiseStrategyBasedIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ItemwiseStrategyBasedIndicator, _super);
    function ItemwiseStrategyBasedIndicator() {
        return _super.call(this) || this;
    }
    ItemwiseStrategyBasedIndicator.prototype.get_yz = function () {
        return new ItemwiseStrategyCalculationStrategy();
    };
    Object.defineProperty(ItemwiseStrategyBasedIndicator.prototype, "yz", {
        get: function () {
            return this.get_yz();
        },
        enumerable: false,
        configurable: true
    });
    ItemwiseStrategyBasedIndicator.prototype.zm = function () {
        return true;
    };
    ItemwiseStrategyBasedIndicator.prototype.zd = function () {
        _super.prototype.zd.call(this);
        this.zk = this.zl;
        this.yy.c = this.zk;
    };
    ItemwiseStrategyBasedIndicator.$t = markType(ItemwiseStrategyBasedIndicator, 'ItemwiseStrategyBasedIndicator', StrategyBasedIndicator.$);
    return ItemwiseStrategyBasedIndicator;
}(StrategyBasedIndicator));
export { ItemwiseStrategyBasedIndicator };
